@@ -24,7 +24,7 @@ import sys
 import tempfile
 
 
-VERSION = "0.38.5"
+VERSION = "0.38.6"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
@@ -150,9 +150,6 @@ CHAR_CR = "\r"
 CHAR_TAB = "\t"
 CHARS_LISTNUM = ".)->"
 NUM_CHARS_LISTNUM = len(CHARS_LISTNUM)
-CHAR_LISTTODO = "☐"
-CHAR_LISTDONEOK= "☑"
-CHAR_LISTDONEFAIL= "☒"
 CHAR_TILDE = "~"
 CHAR_MINUS = "-"
 CHAR_DQUOTE = '"'
