@@ -33,11 +33,15 @@ import exports
 
 def get_timestamp_str(timestamp_format, time_float):
     """Get timestamp printable from float"""
+    try:
+        encoding = locale.getlocale()[1]
+    except:
+        encoding = cons.STR_UTF8
     struct_time = time.localtime(time_float)
     try:
-        timestamp_str = time.strftime(timestamp_format, struct_time).decode(locale.getlocale()[1])
+        timestamp_str = time.strftime(timestamp_format, struct_time).decode(encoding)
     except:
-        timestamp_str = time.strftime(config.TIMESTAMP_FORMAT_DEFAULT, struct_time).decode(locale.getlocale()[1])
+        timestamp_str = time.strftime(config.TIMESTAMP_FORMAT_DEFAULT, struct_time).decode(encoding)
     return timestamp_str
 
 def get_word_count(dad):
@@ -67,7 +71,11 @@ def auto_decode_str(in_str, from_clipboard=False):
         else:
             encodings = [cons.STR_UTF16, cons.STR_UTF8] + encodings
     else:
-        encodings += [cons.STR_UTF16, "utf-16le", cons.STR_UTF8, cons.STR_ISO_8859, locale.getdefaultlocale()[1]]
+        encodings += [cons.STR_UTF16, "utf-16le", cons.STR_UTF8, cons.STR_ISO_8859]
+        try:
+            encodings.append(locale.getdefaultlocale()[1])
+        except:
+            pass
     for enc in encodings:
         try:
             out_str = in_str.decode(enc)
@@ -377,7 +385,7 @@ def on_sourceview_event_after_key_press(dad, text_view, event, syntax_highl):
                 index = list_info["num"]*(-1) - 1
                 text_buffer.insert(iter_insert, pre_spaces+dad.chars_listbul[index]+cons.CHAR_SPACE)
             elif list_info["num"] == 0:
-                text_buffer.insert(iter_insert, pre_spaces+cons.CHAR_LISTTODO+cons.CHAR_SPACE)
+                text_buffer.insert(iter_insert, pre_spaces+dad.chars_todo[0]+cons.CHAR_SPACE)
             else:
                 new_num = list_info["num"] + 1
                 index = list_info["aux"]
@@ -456,7 +464,7 @@ def on_sourceview_event_after_key_press(dad, text_view, event, syntax_highl):
                 elif iter_start.get_char() == cons.CHAR_SQ_BR_CLOSE and iter_start.backward_char():
                     if iter_start.get_line_offset() == 0 and iter_start.get_char() == cons.CHAR_SQ_BR_OPEN:
                         # "[] " becoming "☐ " at line start
-                        dad.special_char_replace(cons.CHAR_LISTTODO, iter_start, iter_insert, text_buffer)
+                        dad.special_char_replace(dad.chars_todo[0], iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_COLON and iter_start.backward_char():
                     if iter_start.get_line_offset() == 0 and iter_start.get_char() == cons.CHAR_COLON:
                         # ":: " becoming "▪ " at line start
